@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -216,6 +213,9 @@ bool IOFireWireAVCUnit::start(IOService *provider)
 {
     OSObject *prop;
     UInt32 type;
+	OSNumber *deviceGUID;
+	unsigned long long guidVal;
+	UInt8 series;
 
     fDevice = OSDynamicCast(IOFireWireNub, provider);
     if(!fDevice)
@@ -292,10 +292,25 @@ bool IOFireWireAVCUnit::start(IOService *provider)
     prop = provider->getProperty(gFireWireVendor_ID);
     if(prop)
         setProperty(gFireWireVendor_ID, prop);
-    prop = provider->getProperty(gFireWire_GUID);
+
+
+	prop = provider->getProperty(gFireWire_GUID);
     if(prop)
+	{
         setProperty(gFireWire_GUID, prop);
-    prop = provider->getProperty(gFireWireProduct_Name);
+
+		// Check the guid to see if this device requires special asynch throttling
+		deviceGUID = OSDynamicCast( OSNumber, prop );
+		guidVal = deviceGUID->unsigned64BitValue();
+		if ((guidVal & 0xFFFFFFFFFF000000LL) == 0x0000850000000000LL)
+		{
+			series = (UInt8) ((guidVal & 0x0000000000FF0000LL) >> 16);
+			if ((series <= 0x13) || ((series >= 0x18) && (series <= 0x23)))
+				fDevice->setNodeFlags( kIOFWLimitAsyncPacketSize );
+		}
+	}
+	
+	prop = provider->getProperty(gFireWireProduct_Name);
     if(prop)
         setProperty(gFireWireProduct_Name, prop);
     
