@@ -2,24 +2,21 @@
  * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ *
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
+ *
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
- * 
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
+ *
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -96,6 +93,7 @@ typedef struct _AVCUnit
 	// notifications
     
     Boolean					fSuspended;
+	Boolean					fHighPerfAVCCommands;
 
 } AVCUnit;
 
@@ -162,6 +160,17 @@ static HRESULT queryInterface( void * self, REFIID iid, void **ppv )
     }
 	else if( CFEqual(uuid, kIOFireWireAVCLibUnitInterfaceID) ) 
 	{
+		// Set flag to throttle AVC Commands
+		me->fHighPerfAVCCommands = false;
+
+        *ppv = &me->fIOFireWireAVCLibUnitInterface;
+        addRef(self);
+    }
+	else if( CFEqual(uuid, kIOFireWireAVCLibUnitInterfaceID_v2) )
+	{
+		// Set flag to not throttle AVC Commands
+		me->fHighPerfAVCCommands = true;
+
         *ppv = &me->fIOFireWireAVCLibUnitInterface;
         addRef(self);
     }
@@ -461,7 +470,13 @@ static IOReturn AVCCommand(void *self, const UInt8 * command, UInt32 cmdLen, UIn
         cmdLen, &outputCnt, (UInt8 *)command, response);
     if(status == kIOReturnSuccess)
         *responseLen = outputCnt;
-    
+
+	if (me->fHighPerfAVCCommands == false)
+	{
+		// sleep for 8 milliseconds to throttle back iMovie
+		usleep( 8 * 1000 );
+	}
+	
     return status;
 }
 
@@ -483,7 +498,13 @@ static IOReturn AVCCommandInGeneration(void *self, UInt32 generation,
         cmdLen+sizeof(UInt32), &outputCnt, annoying, response);
     if(status == kIOReturnSuccess)
         *responseLen = outputCnt;
-    
+
+	if (me->fHighPerfAVCCommands == false)
+	{
+		// sleep for 8 milliseconds to throttle back iMovie
+		usleep( 8 * 1000 );
+	}
+	
     return status;
 }
 
@@ -833,7 +854,8 @@ static IOCFPlugInInterface ** alloc()
         me->fIOFireWireAVCLibUnitInterface.obj = me;
 
 		me->fSuspended = false;
-		
+		me->fHighPerfAVCCommands = false;
+	
       	pthread_mutex_init( &me->fACObjectArrayLock, NULL );
 	    me->fACObjectArray = CFArrayCreateMutable(	kCFAllocatorDefault, 
                                                     2, // capacity 
